rm(list=ls()) #clears Rs memory

library(MASS) # For neg.binom. GLM

#######################################################################################################
### IMPORT FIELD DATA
#######################################################################################################
fulldata <- read.csv("C:/Users/larathoo/Documents/Field_data_processed.csv")

#convert -9,-10 and -8 to NA
fulldata[fulldata == -8] <- NA
fulldata[fulldata == -9] <- NA
fulldata[fulldata == -10] <- NA

#Assign upper and lower road
fulldata$Road <- "Upper"
fulldata$Road[as.numeric(fulldata$Latitude) <= 42.328] <- "Lower"

# Subset only SNPs
snps <- fulldata[,c(18:108)]

# Convert to inbreedR format
snps[snps == 2] <- 0
library(inbreedR)
# calculate sMLH
het <- sMLH(snps)
#append het to data
fulldata$sMLH <- het

#Calculate true total flowers by combining with fruit and aborted flowers
fulldata$TotalFlowers_2014[is.na(fulldata$TotalFlowers_2014)] <- 0
fulldata$TotalFlowers_2015[is.na(fulldata$TotalFlowers_2015)] <- 0
fulldata$TotalFlowers_2016[is.na(fulldata$TotalFlowers_2016)] <- 0
fulldata$TotalFlowers_2017[is.na(fulldata$TotalFlowers_2017)] <- 0

fulldata$TotalFruit_2014[is.na(fulldata$TotalFruit_2014)] <- 0
fulldata$TotalFruit_2015[is.na(fulldata$TotalFruit_2015)] <- 0
fulldata$TotalFruit_2016[is.na(fulldata$TotalFruit_2016)] <- 0
fulldata$TotalFruit_2017[is.na(fulldata$TotalFruit_2017)] <- 0

fulldata$AbortedFlowers_2014[is.na(fulldata$AbortedFlowers_2014)] <- 0
fulldata$AbortedFlowers_2015[is.na(fulldata$AbortedFlowers_2015)] <- 0
fulldata$AbortedFlowers_2016[is.na(fulldata$AbortedFlowers_2016)] <- 0
fulldata$AbortedFlowers_2017[is.na(fulldata$AbortedFlowers_2017)] <- 0

fulldata$allflowers14 <- fulldata$TotalFlowers_2014+fulldata$AbortedFlowers_2014+fulldata$TotalFruit_2014
fulldata$allflowers15 <- fulldata$TotalFlowers_2015+fulldata$AbortedFlowers_2015+fulldata$TotalFruit_2015
fulldata$allflowers16 <- fulldata$TotalFlowers_2016+fulldata$AbortedFlowers_2016+fulldata$TotalFruit_2016
fulldata$allflowers17 <- fulldata$TotalFlowers_2017+fulldata$AbortedFlowers_2017+fulldata$TotalFruit_2017


for(i in 1:nrow(fulldata)){
  if(is.na(fulldata$TotalFlowers_2014[i]) & is.na(fulldata$AbortedFlowers_2014[i]) & is.na(fulldata$TotalFruit_2014[i])){
    fulldata$allflowers14[i] = NA
  } else{
    fulldata$allflowers14[i] <- sum(fulldata$TotalFlowers_2014[i],fulldata$AbortedFlowers_2014[i],fulldata$TotalFruit_2014[i], na.rm = T)
  }
  if(is.na(fulldata$TotalFlowers_2015[i]) & is.na(fulldata$AbortedFlowers_2015[i]) & is.na(fulldata$TotalFruit_2015[i])){
    fulldata$allflowers15[i] = NA
  } else{
    fulldata$allflowers15[i] <- sum(fulldata$TotalFlowers_2015[i],fulldata$AbortedFlowers_2015[i],fulldata$TotalFruit_2015[i],na.rm = T)
  }
  if(is.na(fulldata$TotalFlowers_2016[i]) & is.na(fulldata$AbortedFlowers_2016[i]) & is.na(fulldata$TotalFruit_2016[i])){
    fulldata$allflowers16[i] = NA
  } else{
    fulldata$allflowers16[i] <- sum(fulldata$TotalFlowers_2016[i],fulldata$AbortedFlowers_2016[i],fulldata$TotalFruit_2016[i],na.rm = T)
  }
  if(is.na(fulldata$TotalFlowers_2017[i]) & is.na(fulldata$AbortedFlowers_2017[i]) & is.na(fulldata$TotalFruit_2017[i])){
    fulldata$allflowers17[i] = NA
  } else{
    fulldata$allflowers17[i] <- sum(fulldata$TotalFlowers_2017[i],fulldata$AbortedFlowers_2017[i],fulldata$TotalFruit_2017[i],na.rm = T)
  }
}


#Calculate max value for perennial plants and corresponding year
for (x in 1:nrow(fulldata)){
  if (which.max(c(fulldata$allflowers14[x],fulldata$allflowers15[x],fulldata$allflowers16[x],
                  fulldata$allflowers17[x])) == 1){
    fulldata$FlowersYearNEW[x] <- 2014
  }else if(which.max(c(fulldata$allflowers14[x],fulldata$allflowers15[x],fulldata$allflowers16[x],
                       fulldata$allflowers17[x]))== 2){
    fulldata$FlowersYearNEW[x] <- 2015
  }else if(which.max(c(fulldata$allflowers14[x],fulldata$allflowers15[x],fulldata$allflowers16[x],
                       fulldata$allflowers17[x])) == 3){
    fulldata$FlowersYearNEW[x] <- 2016
  }else if(which.max(c(fulldata$allflowers14[x],fulldata$allflowers15[x],fulldata$allflowers16[x],
                       fulldata$allflowers17[x])) == 4){
    fulldata$FlowersYearNEW[x] <- 2017
  }
}

for (x in 1:nrow(fulldata)){
  value <- which.max(c(fulldata$allflowers14[x],fulldata$allflowers15[x],fulldata$allflowers16[x],fulldata$allflowers17[x]))
  if (value == 1){
    fulldata$TotalFlowersMAXNEW[x] = fulldata$allflowers14[x]
  }else if(value ==2){
    fulldata$TotalFlowersMAXNEW[x] = fulldata$allflowers15[x]
  }else if(value ==3){
    fulldata$TotalFlowersMAXNEW[x] = fulldata$allflowers16[x]
  }else if(value ==4){
    fulldata$TotalFlowersMAXNEW[x] = fulldata$allflowers17[x]
  }
}

################################################################################
### GLM ANALYSIS
################################################################################
### TOTAL FLOWERS
################################################################################

#Make total flowers dataset
fl_data <- fulldata

#Remove zero values
fl_data <- subset(fl_data, fl_data$TotalFlowersMAXNEW > 0)

#Make varaibles factors
fl_data$Road <- as.factor(fl_data$Road) 
fl_data$PerennialNEW <- as.factor(fl_data$PerennialNEW)
fl_data$FlowersYearNEW <- as.factor(fl_data$FlowersYearNEW)

#GLM
fl_glm_91 <- glm.nb(TotalFlowersMAXNEW ~ sMLH + Road + PerennialNEW + FlowersYearNEW, data = fl_data)
summ(fl_glm_91, confint = TRUE)

########################################################################################################
### TOTAL FRUIT
#######################################################################################################

#create fruit dataset from flowers dataset and make variables factors
f_data <- subset(fl_data,!is.na(fl_data$TotalFruitMAX))
f_data$Road <- as.factor(f_data$Road) 
f_data$PerennialNEW <- as.factor(f_data$PerennialNEW)
f_data$FruitYear <- as.factor(f_data$FruitYear)

#Run GLM
f_glm_91 <- glm.nb(TotalFruitMAX ~ sMLH + Road + PerennialNEW + FruitYear, data = f_data)
summ(f_glm_91, confint = TRUE)

########################################################################################################
### ESTIM. FLOWER
########################################################################################################

#Make estimated flowers dataset, remove missing values, outliers, and plants with zero values, and format date variable
e_data <- subset(fulldata, !is.na(fulldata$EstimFlowersMAX))
e_data <- subset(e_data, e_data$EstimFlowersMAX < 500 & e_data$EstimFlowersMAX > 0)
e_data <- subset(e_data, !is.na(e_data$EstimFlowersDate))
e_data$EstimFlowersDate <- as.Date(e_data$EstimFlowersDate,"%m/%d/%Y")

#convert date to Julian Day
for (x in 1:nrow(e_data)){
  if (as.numeric(format(e_data$EstimFlowersDate[x],'%Y'))==2010){
    e_data$JulianDay[x] <- julian(e_data$EstimFlowersDate[x], origin = as.Date("2010-01-01"))
  } else if (as.numeric(format(e_data$EstimFlowersDate[x],'%Y'))==2011){
    e_data$JulianDay[x] <- julian(e_data$EstimFlowersDate[x], origin = as.Date("2011-01-01"))
  }else if (as.numeric(format(e_data$EstimFlowersDate[x],'%Y'))==2012){
    e_data$JulianDay[x] <- julian(e_data$EstimFlowersDate[x], origin = as.Date("2012-01-01"))
  }else if (as.numeric(format(e_data$EstimFlowersDate[x],'%Y'))==2013){
    e_data$JulianDay[x] <- julian(e_data$EstimFlowersDate[x], origin = as.Date("2013-01-01"))
  }else if (as.numeric(format(e_data$EstimFlowersDate[x],'%Y'))==2014){
    e_data$JulianDay[x] <- julian(e_data$EstimFlowersDate[x], origin = as.Date("2014-01-01"))
  }else if (as.numeric(format(e_data$EstimFlowersDate[x],'%Y'))==2015){
    e_data$JulianDay[x] <- julian(e_data$EstimFlowersDate[x], origin = as.Date("2015-01-01"))
  }else if (as.numeric(format(e_data$EstimFlowersDate[x],'%Y'))==2016){
    e_data$JulianDay[x] <- julian(e_data$EstimFlowersDate[x], origin = as.Date("2016-01-01"))
  }else if (as.numeric(format(e_data$EstimFlowersDate[x],'%Y'))==2017){
    e_data$JulianDay[x] <- julian(e_data$EstimFlowersDate[x], origin = as.Date("2017-01-01"))
  }else if (as.numeric(format(e_data$EstimFlowersDate[x],'%Y'))==2018){
    e_data$JulianDay[x] <- julian(e_data$EstimFlowersDate[x], origin = as.Date("2018-01-01"))
  }else if (as.numeric(format(e_data$EstimFlowersDate[x],'%Y'))==2019){
    e_data$JulianDay[x] <- julian(e_data$EstimFlowersDate[x], origin = as.Date("2019-01-01"))
  }
}

#Make variables factors
e_data$Road <- as.factor(e_data$Road) 
e_data$PerennialNEW <- as.factor(e_data$PerennialNEW)
e_data$EstimFlowersYear <- as.factor(e_data$EstimFlowersYear)

#GLM
e_glm_91 <- glm.nb(EstimFlowersMAX ~ sMLH + Road + PerennialNEW + JulianDay + EstimFlowersYear, data = e_data)
summ(e_glm_91, confint = TRUE)

#######################################################################################################
### LEAVES
#######################################################################################################

#Make leaves dataset, remove missing values, plants with zero values, and format date variable
l_data <- subset(fulldata, !is.na(fulldata$LeavesMAX))
l_data <- subset(l_data, LeavesMAX > 0 & LeavesMAX < 90)
l_data$LeavesDate <- as.Date(l_data$LeavesDate,"%m/%d/%Y")

#Convert date to Julian Day
for (x in 1:nrow(l_data)){
  if (as.numeric(format(l_data$LeavesDate[x],'%Y'))==2014){
    l_data$JulianDay[x] <- julian(l_data$LeavesDate[x], origin = as.Date("2014-01-01"))
  }else if (as.numeric(format(l_data$LeavesDate[x],'%Y'))==2015){
    l_data$JulianDay[x] <- julian(l_data$LeavesDate[x], origin = as.Date("2015-01-01"))
  }else if (as.numeric(format(l_data$LeavesDate[x],'%Y'))==2016){
    l_data$JulianDay[x] <- julian(l_data$LeavesDate[x], origin = as.Date("2016-01-01"))
  }else if (as.numeric(format(l_data$LeavesDate[x],'%Y'))==2017){
    l_data$JulianDay[x] <- julian(l_data$LeavesDate[x], origin = as.Date("2017-01-01"))
  }else if (as.numeric(format(l_data$LeavesDate[x],'%Y'))==2018){
    l_data$JulianDay[x] <- julian(l_data$LeavesDate[x], origin = as.Date("2018-01-01"))
  }else if (as.numeric(format(l_data$LeavesDate[x],'%Y'))==2019){
    l_data$JulianDay[x] <- julian(l_data$LeavesDate[x], origin = as.Date("2019-01-01"))
  }
}

#Make variables factors
l_data$Road <- as.factor(l_data$Road) 
l_data$PerennialNEW <- as.factor(l_data$PerennialNEW)
l_data$LeavesYear <- as.factor(l_data$LeavesYear)

#GLM
l_glm_91 <- glm.nb(LeavesMAX ~ sMLH + Road + PerennialNEW + JulianDay + LeavesYear, data = l_data)
summ(l_glm_91, confint = TRUE)


########################################################################################################
### STEM HEIGHT
#######################################################################################################

#Make stem height dataset, remove missing values, outliers, and plants with zero values, and format date variable
s_data <- subset(fulldata, !is.na(fulldata$StemHeightMAX))
s_data <- subset(s_data, !is.na(s_data$StemHeightDate))
s_data <- subset(s_data, StemHeightMAX < 205 & StemHeightMAX > 10)
s_data$StemHeightDate <- as.Date(s_data$StemHeightDate,"%m/%d/%Y")

#Convert date to Julian Day
for (x in 1:nrow(s_data)){
  if (as.numeric(format(s_data$StemHeightDate[x],'%Y'))==2014){
    s_data$JulianDay[x] <- julian(s_data$StemHeightDate[x], origin = as.Date("2014-01-01"))
  }else if (as.numeric(format(s_data$StemHeightDate[x],'%Y'))==2015){
    s_data$JulianDay[x] <- julian(s_data$StemHeightDate[x], origin = as.Date("2015-01-01"))
  }else if (as.numeric(format(s_data$StemHeightDate[x],'%Y'))==2016){
    s_data$JulianDay[x] <- julian(s_data$StemHeightDate[x], origin = as.Date("2016-01-01"))
  }else if (as.numeric(format(s_data$StemHeightDate[x],'%Y'))==2017){
    s_data$JulianDay[x] <- julian(s_data$StemHeightDate[x], origin = as.Date("2017-01-01"))
  }else if (as.numeric(format(s_data$StemHeightDate[x],'%Y'))==2018){
    s_data$JulianDay[x] <- julian(s_data$StemHeightDate[x], origin = as.Date("2018-01-01"))
  }else if (as.numeric(format(s_data$StemHeightDate[x],'%Y'))==2019){
    s_data$JulianDay[x] <- julian(s_data$StemHeightDate[x], origin = as.Date("2019-01-01"))
  }
}

#Make variables factors
s_data$Road <- as.factor(s_data$Road) 
s_data$PerennialNEW <- as.factor(s_data$PerennialNEW)
s_data$StemHeightYear <- as.factor(s_data$StemHeightYear)

#GLM
s_glm_91 <- glm(StemHeightMAX ~ sMLH + Road + PerennialNEW + JulianDay + StemHeightYear, data = s_data, family = Gamma(link = identity))
summ(s_glm_91, confint = T)

########################################################################################################
### NUM FLOWERING STEMS
#######################################################################################################

#Make number of stems dataset, remove missing values, plants with zero values, and format date variable
nf_data <- subset(fulldata, !is.na(fulldata$NumFloweringStemsMAX))
nf_data <- subset(nf_data, NumFloweringStemsMAX > 0)
nf_data <- subset(nf_data, !is.na(nf_data$NumFloweringStemsMAX))
nf_data$NumFloweringStemsDate <- as.Date(nf_data$NumFloweringStemsDate,"%m/%d/%Y")

#Convert date to Julian Day
for (x in 1:nrow(nf_data)){
  if (as.numeric(format(nf_data$NumFloweringStemsDate[x],'%Y'))==2009){
    nf_data$JulianDay[x] <- julian(nf_data$NumFloweringStemsDate[x], origin = as.Date("2009-01-01")) 
  } else if (as.numeric(format(nf_data$NumFloweringStemsDate[x],'%Y'))==2010){
    nf_data$JulianDay[x] <- julian(nf_data$NumFloweringStemsDate[x], origin = as.Date("2010-01-01"))
  } else if (as.numeric(format(nf_data$NumFloweringStemsDate[x],'%Y'))==2011){
    nf_data$JulianDay[x] <- julian(nf_data$NumFloweringStemsDate[x], origin = as.Date("2011-01-01"))
  }else if (as.numeric(format(nf_data$NumFloweringStemsDate[x],'%Y'))==2012){
    nf_data$JulianDay[x] <- julian(nf_data$NumFloweringStemsDate[x], origin = as.Date("2012-01-01"))
  }else if (as.numeric(format(nf_data$NumFloweringStemsDate[x],'%Y'))==2013){
    nf_data$JulianDay[x] <- julian(nf_data$NumFloweringStemsDate[x], origin = as.Date("2013-01-01"))
  }else if (as.numeric(format(nf_data$NumFloweringStemsDate[x],'%Y'))==2014){
    nf_data$JulianDay[x] <- julian(nf_data$NumFloweringStemsDate[x], origin = as.Date("2014-01-01"))
  }else if (as.numeric(format(nf_data$NumFloweringStemsDate[x],'%Y'))==2015){
    nf_data$JulianDay[x] <- julian(nf_data$NumFloweringStemsDate[x], origin = as.Date("2015-01-01"))
  }else if (as.numeric(format(nf_data$NumFloweringStemsDate[x],'%Y'))==2016){
    nf_data$JulianDay[x] <- julian(nf_data$NumFloweringStemsDate[x], origin = as.Date("2016-01-01"))
  }else if (as.numeric(format(nf_data$NumFloweringStemsDate[x],'%Y'))==2017){
    nf_data$JulianDay[x] <- julian(nf_data$NumFloweringStemsDate[x], origin = as.Date("2017-01-01"))
  }else if (as.numeric(format(nf_data$NumFloweringStemsDate[x],'%Y'))==2018){
    nf_data$JulianDay[x] <- julian(nf_data$NumFloweringStemsDate[x], origin = as.Date("2018-01-01"))
  }else if (as.numeric(format(nf_data$NumFloweringStemsDate[x],'%Y'))==2019){
    nf_data$JulianDay[x] <- julian(nf_data$NumFloweringStemsDate[x], origin = as.Date("2019-01-01"))
  }
}

#Make variables factors
nf_data$Road <- as.factor(nf_data$Road) 
nf_data$PerennialNEW <- as.factor(nf_data$PerennialNEW)
nf_data$NumFloweringStemsYear <- as.factor(nf_data$NumFloweringStemsYear)

#GLM
n_glm_91 <- glm.nb(NumFloweringStemsMAX ~ sMLH+ Road+ PerennialNEW+JulianDay+NumFloweringStemsYear, data = nf_data)
summ(n_glm_91, confint=T, exp = T)

n.grad <- exp(coef(n_glm_91)[2])
n.cov <- vcov(n_glm_91)[2,2]
n.vG <- n.grad %*% n.cov %*% n.grad
n.SE <- sqrt(n.vG)

# standardised
n.std <- beta(n_glm_91)

n.grad.std <- exp(coef(n.std)[2])
n.cov.std <- vcov(n.std)[2,2]
n.vG.std <- n.grad.std %*% n.cov.std %*% n.grad.std
n.SE.std <- sqrt(n.vG.std)

##### SPATIAL AUTOCORRELATION ############

nf_data <- subset(nf_data, !duplicated(fulldata$Easting))
nf_data <- subset(nf_data, !duplicated(fulldata$Northing))

### glmmPQL
library(MASS)
library(nlme)

model.base_nf<- glmmPQL(NumFloweringStemsMAX ~ sMLH + PerennialNEW + JulianDay + NumFloweringStemsYear, 
                        random = ~1|Road/NumFloweringStemsYear,
                        data=nf_data,
                        family=poisson)
summary(model.base_nf)

# correlation structure
model.NStem <- glmmPQL(NumFloweringStemsMAX ~ sMLH + PerennialNEW + JulianDay + NumFloweringStemsYear, 
                       random=~1|Road/NumFloweringStemsYear,
                       data=nf_data,
                       correlation=corExp(form=~Easting+Northing|Road/NumFloweringStemsYear, nugget = T),
                       family=poisson)
summary(model.NStem)

######################################################################################################
### RESULTS TABLES AND FIGURES
######################################################################################################

#Make results datafile for all models
result_sMLH <- data.frame(traits = c('Total Fruit','Total Flowers','Estim. Flowers','Leaf Nodes','Stem Height','Flowering Stems'),
                          covariates=c('sMLH','sMLH','sMLH','sMLH','sMLH','sMLH'),
                          coeffs = c(f_glm_91$coefficients[2],fl_glm_91$coefficients[2],e_glm_91$coefficients[2],l_glm_91$coefficients[2],s_glm_91$coefficients[2],n_glm_91$coefficients[2]),
                          sd = c(summary(f_glm_91)$coefficients[2,2]*sqrt(length(f_data$PlantID_final)),
                                 summary(fl_glm_91)$coefficients[2,2]*sqrt(length(fl_data$PlantID_final)),
                                 summary(e_glm_91)$coefficients[2,2]*sqrt(length(e_data$PlantID_final)),
                                 summary(l_glm_91)$coefficients[2,2]*sqrt(length(l_data$PlantID_final)),
                                 summary(s_glm_91)$coefficients[2,2]*sqrt(length(s_data$PlantID_final)),
                                 summary(n_glm_91)$coefficients[2,2]*sqrt(length(nf_data$PlantID_final))),
                          lower_ci=c(f_glm_91$coefficients[2]-(1.96*summary(f_glm_91)$coefficients[2,2]),
                                     fl_glm_91$coefficients[2]-(1.96*summary(fl_glm_91)$coefficients[2,2]),
                                     e_glm_91$coefficients[2]-(1.96*summary(e_glm_91)$coefficients[2,2]),
                                     l_glm_91$coefficients[2]-(1.96*summary(l_glm_91)$coefficients[2,2]),
                                     s_glm_91$coefficients[2]-(1.96*summary(s_glm_91)$coefficients[2,2]),
                                     n_glm_91$coefficients[2]-(1.96*summary(n_glm_91)$coefficients[2,2])),
                          upper_ci=c(f_glm_91$coefficients[2]+(1.96*summary(f_glm_91)$coefficients[2,2]),
                                     fl_glm_91$coefficients[2]+(1.96*summary(fl_glm_91)$coefficients[2,2]),
                                     e_glm_91$coefficients[2]+(1.96*summary(e_glm_91)$coefficients[2,2]),
                                     l_glm_91$coefficients[2]+(1.96*summary(l_glm_91)$coefficients[2,2]),
                                     s_glm_91$coefficients[2]+(1.96*summary(s_glm_91)$coefficients[2,2]),
                                     n_glm_91$coefficients[2]+(1.96*summary(n_glm_91)$coefficients[2,2])))

other_results <- data.frame(covariates = c('sMLH','Road','Perennial','Julian Day','Year 2010','Year 2011','Year 2012','Year 2013','Year 2014','Year 2015','Year 2016','Year 2017','Year 2018','Year 2019'),
                            Total_Fruit_DF=c(anova(f_glm_91)[2,3],anova(f_glm_91)[3,3],anova(f_glm_91)[4,3],"None","None","None","None","None","None",anova(f_glm_91)[5,3],anova(f_glm_91)[6,3],anova(f_glm_91)[7,3],"None","None"),
                            Total_Fruit_Chi=c(drop1(f_glm_91, test = "Chi")[2,4],drop1(f_glm_91, test = "Chi")[3,4],drop1(f_glm_91, test = "Chi")[4,4],"None","None","None","None","None","None",drop1(f_glm_91, test = "Chi")[5,4],drop1(f_glm_91, test = "Chi")[6,4],drop1(f_glm_91, test = "Chi")[7,4],"None","None"),
                            Total_Fruit_p_value=c(drop1(f_glm_91, test = "Chi")[2,5],drop1(f_glm_91, test = "Chi")[3,5],drop1(f_glm_91, test = "Chi")[4,5],"None","None","None","None","None","None",drop1(f_glm_91, test = "Chi")[5,5],drop1(f_glm_91, test = "Chi")[6,5],drop1(f_glm_91, test = "Chi")[7,5],"None","None"),
                            Total_Flowers_DF=c(anova(fl_glm_91)[2,3],anova(fl_glm_91)[3,3],anova(fl_glm_91)[4,3],"None","None","None","None","None","None",anova(fl_glm_91)[5,3],anova(fl_glm_91)[6,3],anova(fl_glm_91)[7,3],"None","None"),
                            Total_Flowers_Chi=c(drop1(fl_glm_91, test = "Chi")[2,4],drop1(fl_glm_91, test = "Chi")[3,4],drop1(fl_glm_91, test = "Chi")[4,4],"None","None","None","None","None","None",drop1(fl_glm_91, test = "Chi")[5,4],drop1(fl_glm_91, test = "Chi")[6,4],drop1(fl_glm_91, test = "Chi")[7,4],"None","None"),
                            Total_Flowers_p_value=c(drop1(fl_glm_91, test = "Chi")[2,5],drop1(fl_glm_91, test = "Chi")[3,5],drop1(fl_glm_91, test = "Chi")[4,5],"None","None","None","None","None","None",drop1(fl_glm_91, test = "Chi")[5,5],drop1(fl_glm_91, test = "Chi")[6,5],drop1(fl_glm_91, test = "Chi")[7,5],"None","None"),
                            Estim_Flower_DF=c(anova(e_glm_91)[2,3],anova(e_glm_91)[3,3],anova(e_glm_91)[4,3],anova(e_glm_91)[5,3],"None",anova(e_glm_91)[6,3],anova(e_glm_91)[7,3],anova(e_glm_91)[8,3],anova(e_glm_91)[9,3],anova(e_glm_91)[10,3],anova(e_glm_91)[11,3],anova(e_glm_91)[12,3],anova(e_glm_91)[13,3],anova(e_glm_91)[14,3]),
                            Estim_Flower_Chi=c(drop1(e_glm_91, test = "Chi")[2,4],drop1(e_glm_91, test = "Chi")[3,4],drop1(e_glm_91, test = "Chi")[4,4],drop1(e_glm_91, test = "Chi")[5,4],"None",drop1(e_glm_91, test = "Chi")[6,4],drop1(e_glm_91, test = "Chi")[7,4],drop1(e_glm_91, test = "Chi")[8,4],drop1(e_glm_91, test = "Chi")[9,4],drop1(e_glm_91, test = "Chi")[10,4],drop1(e_glm_91, test = "Chi")[11,4],drop1(e_glm_91, test = "Chi")[12,4],drop1(e_glm_91, test = "Chi")[13,4],drop1(e_glm_91, test = "Chi")[14,4]),
                            Estim_Flower_p_value=c(drop1(e_glm_91, test = "Chi")[2,5],drop1(e_glm_91, test = "Chi")[3,5],drop1(e_glm_91, test = "Chi")[4,5],drop1(e_glm_91, test = "Chi")[5,5],"None",drop1(e_glm_91, test = "Chi")[6,5],drop1(e_glm_91, test = "Chi")[7,5],drop1(e_glm_91, test = "Chi")[8,5],drop1(e_glm_91, test = "Chi")[9,5],drop1(e_glm_91, test = "Chi")[10,5],drop1(e_glm_91, test = "Chi")[11,5],drop1(e_glm_91, test = "Chi")[12,5],drop1(e_glm_91, test = "Chi")[13,5],drop1(e_glm_91, test = "Chi")[14,5]),
                            Leaves_DF=c(anova(l_glm_91)[2,3],anova(l_glm_91)[3,3],anova(l_glm_91)[4,3],anova(l_glm_91)[5,3],"None","None","None","None","None",anova(l_glm_91)[6,3],anova(l_glm_91)[7,3],anova(l_glm_91)[8,3],anova(l_glm_91)[9,3],anova(l_glm_91)[10,3]),
                            Leaves_Chi=c(drop1(l_glm_91, test = "Chi")[2,4],drop1(l_glm_91, test = "Chi")[3,4],drop1(l_glm_91, test = "Chi")[4,4],drop1(l_glm_91, test = "Chi")[5,4],"None","None","None","None","None",drop1(l_glm_91, test = "Chi")[6,4],drop1(l_glm_91, test = "Chi")[7,4],drop1(l_glm_91, test = "Chi")[8,4],drop1(l_glm_91, test = "Chi")[9,4],drop1(l_glm_91, test = "Chi")[10,4]),
                            Leaves_p_value=c(drop1(l_glm_91, test = "Chi")[2,5],drop1(l_glm_91, test = "Chi")[3,5],drop1(l_glm_91, test = "Chi")[4,5],drop1(l_glm_91, test = "Chi")[5,5],"None","None","None","None","None",drop1(l_glm_91, test = "Chi")[6,5],drop1(l_glm_91, test = "Chi")[7,5],drop1(l_glm_91, test = "Chi")[8,5],drop1(l_glm_91, test = "Chi")[9,5],drop1(l_glm_91, test = "Chi")[10,5]),
                            Stem_Height_DF=c(anova(s_glm_91)[2,3],anova(s_glm_91)[3,3],anova(s_glm_91)[4,3],anova(s_glm_91)[5,3],"None","None","None","None","None",anova(s_glm_91)[6,3],anova(s_glm_91)[7,3],anova(s_glm_91)[8,3],anova(s_glm_91)[9,3],anova(s_glm_91)[10,3]),
                            Stem_Height_Chi=c(drop1(s_glm_91, test = "Chi")[2,4],drop1(s_glm_91, test = "Chi")[3,4],drop1(s_glm_91, test = "Chi")[4,4],drop1(s_glm_91, test = "Chi")[5,4],"None","None","None","None","None",drop1(s_glm_91, test = "Chi")[6,4],drop1(s_glm_91, test = "Chi")[7,4],drop1(s_glm_91, test = "Chi")[8,4],drop1(s_glm_91, test = "Chi")[9,4],drop1(s_glm_91, test = "Chi")[10,4]),
                            Stem_Height_p_value=c(drop1(s_glm_91, test = "Chi")[2,5],drop1(s_glm_91, test = "Chi")[3,5],drop1(s_glm_91, test = "Chi")[4,5],drop1(s_glm_91, test = "Chi")[5,5],"None","None","None","None","None",drop1(s_glm_91, test = "Chi")[6,5],drop1(s_glm_91, test = "Chi")[7,5],drop1(s_glm_91, test = "Chi")[8,5],drop1(s_glm_91, test = "Chi")[9,5],drop1(s_glm_91, test = "Chi")[10,5]),
                            Num_Stems_DF=c(anova(n_glm_91)[2,3],anova(n_glm_91)[3,3],anova(n_glm_91)[4,3],anova(n_glm_91)[5,3],anova(n_glm_91)[6,3],anova(n_glm_91)[7,3],anova(n_glm_91)[8,3],anova(n_glm_91)[9,3],anova(n_glm_91)[10,3],anova(n_glm_91)[11,3],anova(n_glm_91)[12,3],anova(n_glm_91)[13,3],anova(n_glm_91)[14,3],anova(n_glm_91)[15,3]),
                            Num_Stems_Chi=c(drop1(n_glm_91, test = "Chi")[2,4],drop1(n_glm_91, test = "Chi")[3,4],drop1(n_glm_91, test = "Chi")[4,4],drop1(n_glm_91, test = "Chi")[5,4],drop1(n_glm_91, test = "Chi")[6,4],drop1(n_glm_91, test = "Chi")[7,4],drop1(n_glm_91, test = "Chi")[8,4],drop1(n_glm_91, test = "Chi")[9,4],drop1(n_glm_91, test = "Chi")[10,4],drop1(n_glm_91, test = "Chi")[11,4],drop1(n_glm_91, test = "Chi")[12,4],drop1(n_glm_91, test = "Chi")[13,4],drop1(n_glm_91, test = "Chi")[14,4],drop1(n_glm_91, test = "Chi")[15,4]),
                            Num_Stems_p_value=c(drop1(n_glm_91, test = "Chi")[2,5],drop1(n_glm_91, test = "Chi")[3,5],drop1(n_glm_91, test = "Chi")[4,5],drop1(n_glm_91, test = "Chi")[5,5],drop1(n_glm_91, test = "Chi")[6,5],drop1(n_glm_91, test = "Chi")[7,5],drop1(n_glm_91, test = "Chi")[8,5],drop1(n_glm_91, test = "Chi")[9,5],drop1(n_glm_91, test = "Chi")[10,5],drop1(n_glm_91, test = "Chi")[11,5],drop1(n_glm_91, test = "Chi")[12,5],drop1(n_glm_91, test = "Chi")[13,5],drop1(n_glm_91, test = "Chi")[14,5],drop1(n_glm_91, test = "Chi")[15,5]))

library(ggplot2)
ggplot(result_sMLH,aes(x=traits, y=coeffs)) + 
  geom_errorbar(aes(ymin=lower_ci, ymax=upper_ci),size=.4,width=0, position=position_dodge(width=0.7))+
  geom_point(size = 2, position=position_dodge(width=0.7)) +
  geom_hline(yintercept=0,linetype="dashed") +
  ylab("Regression coefficient")  +
  xlab("Fitness proxy traits")+
  theme_classic() + theme(text = element_text(size = 16))

#######################################################################################################
### INBREEDING DEPRESSION
#######################################################################################################

#### Beta (inbreeding load) calc

H_bar <- mean(het, na.rm = T)
H_var <- var(het, na.rm = T)
g2_HFC <- g2_snps(snps, nperm = 100, nboot = 100)

Beta.fh <- -(H_bar*as.numeric(g2_HFC[2]))/H_var

### Make data table of inbreeding data
Inbreeding_data <- data.frame(traits = c("Total Fruit","Total Flowers","Estimated Flowers","Leaf Nodes","Stem Height","Number of Flowering Stems"),
                              Beta = c(f_glm_91$coefficients[2]/Beta.fh,fl_glm_91$coefficients[2]/Beta.fh,e_glm_91$coefficients[2]/Beta.fh,l_glm_91$coefficients[2]/Beta.fh,s_glm_91$coefficients[2]/Beta.fh,n_glm_91$coefficients[2]/Beta.fh),
                              Beta_lowerCI = c((f_glm_91$coefficients[2]-(1.96*summary(f_glm_91)$coefficients[2,2]))/Beta.fh,
                                               (fl_glm_91$coefficients[2]-(1.96*summary(fl_glm_91)$coefficients[2,2]))/Beta.fh,
                                               (e_glm_91$coefficients[2]-(1.96*summary(e_glm_91)$coefficients[2,2]))/Beta.fh,
                                               (l_glm_91$coefficients[2]-(1.96*summary(l_glm_91)$coefficients[2,2]))/Beta.fh,
                                               (s_glm_91$coefficients[2]-(1.96*summary(s_glm_91)$coefficients[2,2]))/Beta.fh,
                                               (n_glm_91$coefficients[2]-(1.96*summary(n_glm_91)$coefficients[2,2]))/Beta.fh),
                              Beta_upperCI = c((f_glm_91$coefficients[2]+(1.96*summary(f_glm_91)$coefficients[2,2]))/Beta.fh,
                                               (fl_glm_91$coefficients[2]+(1.96*summary(fl_glm_91)$coefficients[2,2]))/Beta.fh,
                                               (e_glm_91$coefficients[2]+(1.96*summary(e_glm_91)$coefficients[2,2]))/Beta.fh,
                                               (l_glm_91$coefficients[2]+(1.96*summary(l_glm_91)$coefficients[2,2]))/Beta.fh,
                                               (s_glm_91$coefficients[2]+(1.96*summary(s_glm_91)$coefficients[2,2]))/Beta.fh,
                                               (n_glm_91$coefficients[2]+(1.96*summary(n_glm_91)$coefficients[2,2]))/Beta.fh))

################################################################################
################################################################################ 
### G2 calculations
################################################################################
library(inbreedR)

################################ DATA FOR G2 ###################################

### ALL YEARS FIELD ###

#import field data for 91 SNPs
field_snps <- read.csv("C:/Users/larathoo/Documents/inbreeding paper/20210215_NewSubmissionFiles/Field_data_processed.csv")

#convert -9,-10 and -8 to NA
field_snps[field_snps == -8] <- NA
field_snps[field_snps == -9] <- NA
field_snps[field_snps == -10] <- NA

# Subset only SNPs
field_snps <- field_snps[,c(18:108)]

# Convert to inbreedR format
field_snps[field_snps == 2] <- 0

library(inbreedR)
#calculate g2
g2_field <- g2_snps(field_snps, nperm = 100, nboot = 100)

### POLLEN DISPERSAL SIMULATION DATA ###

#import gaussian data for 91 SNPs
gauss_snps <- read.csv("C:/Users/larathoo/Documents/Simulated_offspring/Simulated Gaussian offspring 7 Aug.csv")

#convert -9,-10 and -8 to NA
gauss_snps[gauss_snps == -8] <- NA
gauss_snps[gauss_snps == -9] <- NA
gauss_snps[gauss_snps == -10] <- NA

# Convert to inbreedR format
gauss_snps[gauss_snps == 2] <- 0

g2_gauss <- g2_snps(gauss_snps, nperm = 100, nboot = 100)

#import nearest data for 91 SNPs
near_snps <- read.csv("C:/Users/larathoo/Documents/Simulated_offspring/Simulated nearest offspring 7 Aug.csv")

#convert -9,-10 and -8 to NA
near_snps[near_snps == -8] <- NA
near_snps[near_snps == -9] <- NA
near_snps[near_snps == -10] <- NA

# Convert to inbreedR format
near_snps[near_snps == 2] <- 0

g2_near <- g2_snps(near_snps, nperm = 100, nboot = 100)

#import realistic data for 91 SNPs
real_snps <- read.csv("C:/Users/larathoo/Documents/Simulated_offspring/Simulated realistic offspring 7 Aug.csv")

#convert -9,-10 and -8 to NA
real_snps[real_snps == -8] <- NA
real_snps[real_snps == -9] <- NA
real_snps[real_snps == -10] <- NA

# Convert to inbreedR format
real_snps[real_snps == 2] <- 0

g2_real <- g2_snps(real_snps, nperm = 100, nboot = 100)

#Make the data file
all_g2 = g2_field$g2
g2_titles <- c('Field')
p_vals <- g2_field$p_val
CI_2.5 <- g2_field$CI_boot[["2.5%"]]
CI_97.5 <- g2_field$CI_boot[["97.5%"]]

g2_fieldDATA <- data.frame(g2_titles, all_g2, p_vals, CI_2.5, CI_97.5)

all_g2 = g2_gauss$g2
g2_titles <- c('Gaussian')
p_vals <- g2_gauss$p_val
CI_2.5 <- g2_gauss$CI_boot[["2.5%"]]
CI_97.5 <- g2_gauss$CI_boot[["97.5%"]]

g2_gaussD <- data.frame(g2_titles, all_g2, p_vals, CI_2.5, CI_97.5)
g2_dataNEW2 <- rbind(g2_fieldDATA, g2_gaussD)

all_g2 = g2_near$g2
g2_titles <- c('Nearest')
p_vals <- g2_near$p_val
CI_2.5 <- g2_near$CI_boot[["2.5%"]]
CI_97.5 <- g2_near$CI_boot[["97.5%"]]

g2_nearD <- data.frame(g2_titles, all_g2, p_vals, CI_2.5, CI_97.5)
g2_dataNEW2 <- rbind(g2_dataNEW2, g2_nearD)

all_g2 = g2_real$g2
g2_titles <- c('Leptokurtic')
p_vals <- g2_real$p_val
CI_2.5 <- g2_real$CI_boot[["2.5%"]]
CI_97.5 <- g2_real$CI_boot[["97.5%"]]

g2_realD <- data.frame(g2_titles, all_g2, p_vals, CI_2.5, CI_97.5)
g2_dataNEW2 <- rbind(g2_dataNEW2, g2_realD)

library(ggplot2)
ggplot(g2_dataNEW2,aes(x=g2_titles, y=all_g2, fill=g2_titles)) + 
  geom_errorbar(aes(ymin=CI_2.5, ymax=CI_97.5),size=.4,width=0, position=position_dodge(width=0.7))  + 
  geom_point(size = 2, position=position_dodge(width=0.7), aes(colour = g2_titles))  + 
  ylab(expression("g"[2])) + geom_hline(yintercept=0,linetype="dashed") + 
  scale_x_discrete(name = "Distance between parents") + 
  theme_classic() + theme(text = element_text(size = 16))+ 
  theme(legend.position = "none")+
  scale_color_manual(values=c("blue","orange","grey","green"))

#percent difference
Percent_diff <- mean(g2_dataNEW2[2,2],g2_dataNEW2[3,2])/mean(g2_dataNEW2[1,2],g2_dataNEW2[4,2])

######################################################################################################
### PEDIGREE SIMULATION FIGURE 3
######################################################################################################
library(Rmisc)

#import simulation data
##### pedigree 1 #####
sim_data1 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree1_PS/ped1gene_1.csv", header = FALSE)
sim_data2 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree1_PS/ped1gene_2.csv", header = FALSE)
sim_data3 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree1_PS/ped1gene_3.csv", header = FALSE)
sim_data4 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree1_PS/ped1gene_4.csv", header = FALSE)
sim_data5 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree1_PS/ped1gene_5.csv", header = FALSE)
sim_data6 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree1_PS/ped1gene_6.csv", header = FALSE)
sim_data7 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree1_PS/ped1gene_7.csv", header = FALSE)
sim_data8 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree1_PS/ped1gene_8.csv", header = FALSE)
sim_data9 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree1_PS/ped1gene_9.csv", header = FALSE)
sim_data10 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree1_PS/ped1gene_10.csv", header = FALSE)

#calculate g2
g2_sim1 <- g2_snps(sim_data1, nperm = 100, nboot = 100)
g2_sim2 <- g2_snps(sim_data2, nperm = 100, nboot = 100)
g2_sim3 <- g2_snps(sim_data3, nperm = 100, nboot = 100)
g2_sim4 <- g2_snps(sim_data4, nperm = 100, nboot = 100)
g2_sim5 <- g2_snps(sim_data5, nperm = 100, nboot = 100)
g2_sim6 <- g2_snps(sim_data6, nperm = 100, nboot = 100)
g2_sim7 <- g2_snps(sim_data7, nperm = 100, nboot = 100)
g2_sim8 <- g2_snps(sim_data8, nperm = 100, nboot = 100)
g2_sim9 <- g2_snps(sim_data9, nperm = 100, nboot = 100)
g2_sim10 <- g2_snps(sim_data10, nperm = 100, nboot = 100)

#mean of pedigree 1
mean_ped1 <- mean(c(g2_sim1$g2,g2_sim2$g2,g2_sim3$g2,g2_sim4$g2,g2_sim5$g2,
                    g2_sim6$g2,g2_sim7$g2,g2_sim8$g2,g2_sim9$g2,g2_sim10$g2))
#SD of pedigree 1
sd_ped1 <- sd(c(g2_sim1$g2,g2_sim2$g2,g2_sim3$g2,g2_sim4$g2,g2_sim5$g2,
                g2_sim6$g2,g2_sim7$g2,g2_sim8$g2,g2_sim9$g2,g2_sim10$g2))

##### pedigree 2 #####
sim_data21 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree2_PS/ped2gene_1.csv", header = FALSE)
sim_data22 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree2_PS/ped2gene_2.csv", header = FALSE)
sim_data23 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree2_PS/ped2gene_3.csv", header = FALSE)
sim_data24 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree2_PS/ped2gene_4.csv", header = FALSE)
sim_data25 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree2_PS/ped2gene_5.csv", header = FALSE)
sim_data26 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree2_PS/ped2gene_1.csv", header = FALSE)
sim_data27 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree2_PS/ped2gene_2.csv", header = FALSE)
sim_data28 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree2_PS/ped2gene_3.csv", header = FALSE)
sim_data29 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree2_PS/ped2gene_4.csv", header = FALSE)
sim_data210 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree2_PS/ped2gene_5.csv", header = FALSE)

#calculate g2
g2_sim21 <- g2_snps(sim_data21, nperm = 100, nboot = 100)
g2_sim22 <- g2_snps(sim_data22, nperm = 100, nboot = 100)
g2_sim23 <- g2_snps(sim_data23, nperm = 100, nboot = 100)
g2_sim24 <- g2_snps(sim_data24, nperm = 100, nboot = 100)
g2_sim25 <- g2_snps(sim_data25, nperm = 100, nboot = 100)
g2_sim26 <- g2_snps(sim_data26, nperm = 100, nboot = 100)
g2_sim27 <- g2_snps(sim_data27, nperm = 100, nboot = 100)
g2_sim28 <- g2_snps(sim_data28, nperm = 100, nboot = 100)
g2_sim29 <- g2_snps(sim_data29, nperm = 100, nboot = 100)
g2_sim210 <- g2_snps(sim_data210, nperm = 100, nboot = 100)

#mean
mean_ped2 <- mean(c(g2_sim21$g2,g2_sim22$g2,g2_sim23$g2,g2_sim24$g2,g2_sim25$g2,
                    g2_sim26$g2,g2_sim27$g2,g2_sim28$g2,g2_sim29$g2,g2_sim210$g2))
#SD
sd_ped2 <- sd(c(g2_sim21$g2,g2_sim22$g2,g2_sim23$g2,g2_sim24$g2,g2_sim25$g2,
                g2_sim26$g2,g2_sim27$g2,g2_sim28$g2,g2_sim29$g2,g2_sim210$g2))

##### pedigree 3 #####
sim_data31 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree3_PS/ped3gene_1.csv", header = FALSE)
sim_data32 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree3_PS/ped3gene_2.csv", header = FALSE)
sim_data33 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree3_PS/ped3gene_3.csv", header = FALSE)
sim_data34 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree3_PS/ped3gene_4.csv", header = FALSE)
sim_data35 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree3_PS/ped3gene_5.csv", header = FALSE)
sim_data36 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree3_PS/ped3gene_6.csv", header = FALSE)
sim_data37 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree3_PS/ped3gene_7.csv", header = FALSE)
sim_data38 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree3_PS/ped3gene_8.csv", header = FALSE)
sim_data39 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree3_PS/ped3gene_9.csv", header = FALSE)
sim_data310 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree3_PS/ped3gene_10.csv", header = FALSE)

#calculate g2
g2_sim31 <- g2_snps(sim_data31, nperm = 100, nboot = 100)
g2_sim32 <- g2_snps(sim_data32, nperm = 100, nboot = 100)
g2_sim33 <- g2_snps(sim_data33, nperm = 100, nboot = 100)
g2_sim34 <- g2_snps(sim_data34, nperm = 100, nboot = 100)
g2_sim35 <- g2_snps(sim_data35, nperm = 100, nboot = 100)
g2_sim36 <- g2_snps(sim_data36, nperm = 100, nboot = 100)
g2_sim37 <- g2_snps(sim_data37, nperm = 100, nboot = 100)
g2_sim38 <- g2_snps(sim_data38, nperm = 100, nboot = 100)
g2_sim39 <- g2_snps(sim_data39, nperm = 100, nboot = 100)
g2_sim310 <- g2_snps(sim_data310, nperm = 100, nboot = 100)

mean_ped3 <- mean(c(g2_sim31$g2,g2_sim32$g2,g2_sim33$g2,g2_sim34$g2,g2_sim35$g2,
                    g2_sim36$g2,g2_sim37$g2,g2_sim38$g2,g2_sim39$g2,g2_sim310$g2))
sd_ped3 <- sd(c(g2_sim31$g2,g2_sim32$g2,g2_sim33$g2,g2_sim34$g2,g2_sim35$g2,
                g2_sim36$g2,g2_sim37$g2,g2_sim38$g2,g2_sim39$g2,g2_sim310$g2))

##### pedigree 4 #####
sim_data41 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree4_PS/ped4gene_1.csv", header = FALSE)
sim_data42 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree4_PS/ped4gene_2.csv", header = FALSE)
sim_data43 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree4_PS/ped4gene_3.csv", header = FALSE)
sim_data44 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree4_PS/ped4gene_4.csv", header = FALSE)
sim_data45 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree4_PS/ped4gene_5.csv", header = FALSE)
sim_data46 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree4_PS/ped4gene_6.csv", header = FALSE)
sim_data47 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree4_PS/ped4gene_7.csv", header = FALSE)
sim_data48 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree4_PS/ped4gene_8.csv", header = FALSE)
sim_data49 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree4_PS/ped4gene_9.csv", header = FALSE)
sim_data410 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree4_PS/ped4gene_10.csv", header = FALSE)

#calculate g2
g2_sim41 <- g2_snps(sim_data41, nperm = 100, nboot = 100)
g2_sim42 <- g2_snps(sim_data42, nperm = 100, nboot = 100)
g2_sim43 <- g2_snps(sim_data43, nperm = 100, nboot = 100)
g2_sim44 <- g2_snps(sim_data44, nperm = 100, nboot = 100)
g2_sim45 <- g2_snps(sim_data45, nperm = 100, nboot = 100)
g2_sim46 <- g2_snps(sim_data46, nperm = 100, nboot = 100)
g2_sim47 <- g2_snps(sim_data47, nperm = 100, nboot = 100)
g2_sim48 <- g2_snps(sim_data48, nperm = 100, nboot = 100)
g2_sim49 <- g2_snps(sim_data49, nperm = 100, nboot = 100)
g2_sim410 <- g2_snps(sim_data410, nperm = 100, nboot = 100)

mean_ped4 <- mean(c(g2_sim41$g2,g2_sim42$g2,g2_sim43$g2,g2_sim44$g2,g2_sim45$g2,
                    g2_sim46$g2,g2_sim47$g2,g2_sim48$g2,g2_sim49$g2,g2_sim410$g2))
sd_ped4 <- sd(c(g2_sim41$g2,g2_sim42$g2,g2_sim43$g2,g2_sim44$g2,g2_sim45$g2,
                g2_sim46$g2,g2_sim47$g2,g2_sim48$g2,g2_sim49$g2,g2_sim410$g2))

##### pedigree 5 #####
sim_data51 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree5_PS/ped5gene_1.csv", header = FALSE)
sim_data52 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree5_PS/ped5gene_2.csv", header = FALSE)
sim_data53 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree5_PS/ped5gene_3.csv", header = FALSE)
sim_data54 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree5_PS/ped5gene_4.csv", header = FALSE)
sim_data55 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree5_PS/ped5gene_5.csv", header = FALSE)
sim_data56 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree5_PS/ped5gene_6.csv", header = FALSE)
sim_data57 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree5_PS/ped5gene_7.csv", header = FALSE)
sim_data58 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree5_PS/ped5gene_8.csv", header = FALSE)
sim_data59 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree5_PS/ped5gene_9.csv", header = FALSE)
sim_data510 <- read.csv("C:/Users/larathoo/Documents/20210104_Pedigree5_PS/ped5gene_10.csv", header = FALSE)

#calculate g2
g2_sim51 <- g2_snps(sim_data51, nperm = 100, nboot = 100)
g2_sim52 <- g2_snps(sim_data52, nperm = 100, nboot = 100)
g2_sim53 <- g2_snps(sim_data53, nperm = 100, nboot = 100)
g2_sim54 <- g2_snps(sim_data54, nperm = 100, nboot = 100)
g2_sim55 <- g2_snps(sim_data55, nperm = 100, nboot = 100)
g2_sim56 <- g2_snps(sim_data56, nperm = 100, nboot = 100)
g2_sim57 <- g2_snps(sim_data57, nperm = 100, nboot = 100)
g2_sim58 <- g2_snps(sim_data58, nperm = 100, nboot = 100)
g2_sim59 <- g2_snps(sim_data59, nperm = 100, nboot = 100)
g2_sim510 <- g2_snps(sim_data510, nperm = 100, nboot = 100)

mean_ped5 <- mean(c(g2_sim51$g2,g2_sim52$g2,g2_sim53$g2,g2_sim54$g2,g2_sim55$g2,
                    g2_sim56$g2,g2_sim57$g2,g2_sim58$g2,g2_sim59$g2,g2_sim510$g2))
sd_ped5 <- sd(c(g2_sim51$g2,g2_sim52$g2,g2_sim53$g2,g2_sim54$g2,g2_sim55$g2,
                g2_sim56$g2,g2_sim57$g2,g2_sim58$g2,g2_sim59$g2,g2_sim510$g2))

#make data frame of g2 and CIs
all_g2 <- c(g2_sim1$g2, g2_sim2$g2, g2_sim3$g2, g2_sim4$g2, g2_sim5$g2, 
            g2_sim21$g2, g2_sim22$g2, g2_sim23$g2, g2_sim24$g2, g2_sim25$g2, 
            g2_sim31$g2, g2_sim32$g2, g2_sim33$g2, g2_sim34$g2, g2_sim35$g2, 
            g2_sim41$g2, g2_sim42$g2, g2_sim43$g2, g2_sim44$g2, g2_sim45$g2,
            g2_sim51$g2, g2_sim52$g2, g2_sim53$g2, g2_sim54$g2, g2_sim55$g2)
g2_titles <- c('01','02','03','04','05',
               '06','07','08','09','10',
               '11','12','13','14','15',
               '16','17','18','19','20',
               '21','22','23','24','25')
p_vals <- c(g2_sim1$p_val, g2_sim2$p_val, g2_sim3$p_val, g2_sim4$p_val, g2_sim5$p_val, 
            g2_sim21$p_val, g2_sim22$p_val, g2_sim23$p_val, g2_sim24$p_val, g2_sim25$p_val, 
            g2_sim31$p_val, g2_sim32$p_val, g2_sim33$p_val, g2_sim34$p_val, g2_sim35$p_val, 
            g2_sim41$p_val, g2_sim42$p_val, g2_sim43$p_val, g2_sim44$p_val, g2_sim45$p_val,
            g2_sim51$p_val, g2_sim52$p_val, g2_sim53$p_val, g2_sim54$p_val, g2_sim55$p_val)
CI_2.5 <- c(g2_sim1$CI_boot[["2.5%"]],g2_sim2$CI_boot[["2.5%"]],g2_sim3$CI_boot[["2.5%"]],g2_sim4$CI_boot[["2.5%"]],g2_sim5$CI_boot[["2.5%"]],
            g2_sim21$CI_boot[["2.5%"]],g2_sim22$CI_boot[["2.5%"]],g2_sim23$CI_boot[["2.5%"]],g2_sim24$CI_boot[["2.5%"]],g2_sim25$CI_boot[["2.5%"]],
            g2_sim31$CI_boot[["2.5%"]],g2_sim32$CI_boot[["2.5%"]],g2_sim33$CI_boot[["2.5%"]],g2_sim34$CI_boot[["2.5%"]],g2_sim35$CI_boot[["2.5%"]],
            g2_sim41$CI_boot[["2.5%"]],g2_sim42$CI_boot[["2.5%"]],g2_sim43$CI_boot[["2.5%"]],g2_sim44$CI_boot[["2.5%"]],g2_sim45$CI_boot[["2.5%"]],
            g2_sim51$CI_boot[["2.5%"]],g2_sim52$CI_boot[["2.5%"]],g2_sim53$CI_boot[["2.5%"]],g2_sim54$CI_boot[["2.5%"]],g2_sim55$CI_boot[["2.5%"]])
CI_97.5 <- c(g2_sim1$CI_boot[["97.5%"]],g2_sim2$CI_boot[["97.5%"]],g2_sim3$CI_boot[["97.5%"]],g2_sim4$CI_boot[["97.5%"]],g2_sim5$CI_boot[["97.5%"]],
             g2_sim21$CI_boot[["97.5%"]],g2_sim22$CI_boot[["97.5%"]],g2_sim23$CI_boot[["97.5%"]],g2_sim24$CI_boot[["97.5%"]],g2_sim25$CI_boot[["97.5%"]],
             g2_sim31$CI_boot[["97.5%"]],g2_sim32$CI_boot[["97.5%"]],g2_sim33$CI_boot[["97.5%"]],g2_sim34$CI_boot[["97.5%"]],g2_sim35$CI_boot[["97.5%"]],
             g2_sim41$CI_boot[["97.5%"]],g2_sim42$CI_boot[["97.5%"]],g2_sim43$CI_boot[["97.5%"]],g2_sim44$CI_boot[["97.5%"]],g2_sim45$CI_boot[["97.5%"]],
             g2_sim51$CI_boot[["97.5%"]],g2_sim52$CI_boot[["97.5%"]],g2_sim53$CI_boot[["97.5%"]],g2_sim54$CI_boot[["97.5%"]],g2_sim55$CI_boot[["97.5%"]])
Pedigree <- c('Het.Dist.1','Het.Dist.1','Het.Dist.1','Het.Dist.1','Het.Dist.1',
              'Het.Dist.2','Het.Dist.2','Het.Dist.2','Het.Dist.2','Het.Dist.2',
              'Het.Dist.3','Het.Dist.3','Het.Dist.3','Het.Dist.3','Het.Dist.3',
              'Het.Dist.4','Het.Dist.4','Het.Dist.4','Het.Dist.4','Het.Dist.4',
              'Het.Dist.5','Het.Dist.5','Het.Dist.5','Het.Dist.5','Het.Dist.5')
Data <- c('Replicate 1','Replicate 2','Replicate 3','Replicate 4','Replicate 5',
          'Replicate 1','Replicate 2','Replicate 3','Replicate 4','Replicate 5',
          'Replicate 1','Replicate 2','Replicate 3','Replicate 4','Replicate 5',
          'Replicate 1','Replicate 2','Replicate 3','Replicate 4','Replicate 5',
          'Replicate 1','Replicate 2','Replicate 3','Replicate 4','Replicate 5')

g2_data <- data.frame(g2_titles, all_g2, p_vals, CI_2.5, CI_97.5, Pedigree, Data)

#Mean of pedigrees grouped
mean <- mean(c(g2_sim1$g2, g2_sim2$g2, g2_sim3$g2, g2_sim4$g2, g2_sim5$g2,
               g2_sim6$g2, g2_sim7$g2, g2_sim8$g2, g2_sim9$g2, g2_sim10$g2,
               g2_sim21$g2, g2_sim22$g2, g2_sim23$g2, g2_sim24$g2, g2_sim25$g2,
               g2_sim26$g2, g2_sim27$g2, g2_sim28$g2, g2_sim29$g2, g2_sim210$g2,
               g2_sim31$g2, g2_sim32$g2, g2_sim33$g2, g2_sim34$g2, g2_sim35$g2,
               g2_sim36$g2, g2_sim37$g2, g2_sim38$g2, g2_sim39$g2, g2_sim310$g2,
               g2_sim41$g2, g2_sim42$g2, g2_sim43$g2, g2_sim44$g2, g2_sim45$g2,
               g2_sim46$g2, g2_sim47$g2, g2_sim48$g2, g2_sim49$g2, g2_sim410$g2,
               g2_sim51$g2, g2_sim52$g2, g2_sim53$g2, g2_sim54$g2, g2_sim55$g2,
               g2_sim56$g2, g2_sim57$g2, g2_sim58$g2, g2_sim59$g2, g2_sim510$g2))
CI <- CI(c(g2_sim1$g2, g2_sim2$g2, g2_sim3$g2, g2_sim4$g2, g2_sim5$g2,
           g2_sim6$g2, g2_sim7$g2, g2_sim8$g2, g2_sim9$g2, g2_sim10$g2,
           g2_sim21$g2, g2_sim22$g2, g2_sim23$g2, g2_sim24$g2, g2_sim25$g2,
           g2_sim26$g2, g2_sim27$g2, g2_sim28$g2, g2_sim29$g2, g2_sim210$g2,
           g2_sim31$g2, g2_sim32$g2, g2_sim33$g2, g2_sim34$g2, g2_sim35$g2,
           g2_sim36$g2, g2_sim37$g2, g2_sim38$g2, g2_sim39$g2, g2_sim310$g2,
           g2_sim41$g2, g2_sim42$g2, g2_sim43$g2, g2_sim44$g2, g2_sim45$g2,
           g2_sim46$g2, g2_sim47$g2, g2_sim48$g2, g2_sim49$g2, g2_sim410$g2,
           g2_sim51$g2, g2_sim52$g2, g2_sim53$g2, g2_sim54$g2, g2_sim55$g2,
           g2_sim56$g2, g2_sim57$g2, g2_sim58$g2, g2_sim59$g2, g2_sim510$g2),
         ci=0.95)
SD <- sd(c(g2_sim1$g2, g2_sim2$g2, g2_sim3$g2, g2_sim4$g2, g2_sim5$g2,
           g2_sim6$g2, g2_sim7$g2, g2_sim8$g2, g2_sim9$g2, g2_sim10$g2,
           g2_sim21$g2, g2_sim22$g2, g2_sim23$g2, g2_sim24$g2, g2_sim25$g2,
           g2_sim26$g2, g2_sim27$g2, g2_sim28$g2, g2_sim29$g2, g2_sim210$g2,
           g2_sim31$g2, g2_sim32$g2, g2_sim33$g2, g2_sim34$g2, g2_sim35$g2,
           g2_sim36$g2, g2_sim37$g2, g2_sim38$g2, g2_sim39$g2, g2_sim310$g2,
           g2_sim41$g2, g2_sim42$g2, g2_sim43$g2, g2_sim44$g2, g2_sim45$g2,
           g2_sim46$g2, g2_sim47$g2, g2_sim48$g2, g2_sim49$g2, g2_sim410$g2,
           g2_sim51$g2, g2_sim52$g2, g2_sim53$g2, g2_sim54$g2, g2_sim55$g2,
           g2_sim56$g2, g2_sim57$g2, g2_sim58$g2, g2_sim59$g2, g2_sim510$g2))

all_g2 = mean
g2_titles <- 'Mean Ped'
pvals <- NA
CI_2.5 <- CI[3]
CI_97.5 <- CI[1]
Pedigree <- "Mean Het.Dist."
Data <- "Mean Ped"

g2_data2 <- data.frame(g2_titles, all_g2, p_vals, CI_2.5, CI_97.5, Pedigree, Data)
g2_data2 <- g2_data2[1,]
g2_data <- rbind(g2_data, g2_data2)

# Mean and sd within pedigrees
mean_within <- mean(c(mean_ped1, mean_ped2, mean_ped3, mean_ped4, mean_ped5))
sd_within <- mean(c(sd_ped1, sd_ped2, sd_ped3, sd_ped4, sd_ped5)) 

### ALL YEARS FIELD ###
#import field data for 91 SNPs
field_snps <- read.csv("C:/Users/larathoo/Documents/Field_data_processed.csv")

#convert -9,-10 and -8 to NA
field_snps[field_snps == -8] <- NA
field_snps[field_snps == -9] <- NA
field_snps[field_snps == -10] <- NA

#Subset smaller area for second figure
field_snps_filt <- subset(field_snps, field_snps$Easting > 423400 & field_snps$Easting < 424500 & field_snps$Northing > 4685500 & field_snps$Northing < 46875000)
#Subset Each Year
field_snps19 <- subset(field_snps_filt,field_snps_filt$AliveRec_2019 == 1)
field_snps18 <- subset(field_snps_filt,field_snps_filt$AliveRec_2018 == 1)
field_snps17 <- subset(field_snps_filt,field_snps_filt$AliveRec_2017 == 1)
field_snps16 <- subset(field_snps_filt,field_snps_filt$AliveRec_2016 == 1)
field_snps15 <- subset(field_snps_filt,field_snps_filt$AliveRec_2015 == 1)
field_snps14 <- subset(field_snps_filt,field_snps_filt$AliveRec_2014 == 1)
field_snps13 <- subset(field_snps_filt,field_snps_filt$AliveRec_2013 == 1)
field_snps12 <- subset(field_snps_filt,field_snps_filt$AliveRec_2012 == 1)
field_snps11 <- subset(field_snps_filt,field_snps_filt$AliveRec_2011 == 1)
field_snps10 <- subset(field_snps_filt,field_snps_filt$AliveRec_2010 == 1)
field_snps09 <- subset(field_snps_filt,field_snps_filt$AliveRec_2009 == 1)

#### Field SNPs for each year
### 2019

# Subset only SNPs
field_snps19 <- field_snps19[,c(18:108)]

# Convert to inbreedR format
field_snps19[field_snps19 == 2] <- 0

#calculate g2
g2_field19 <- g2_snps(field_snps19, nperm = 100, nboot = 100)

### 2018

# Subset only SNPs
field_snps18 <- field_snps18[,c(18:108)]

# Convert to inbreedR format
field_snps18[field_snps18 == 2] <- 0

#calculate g2
g2_field18 <- g2_snps(field_snps18, nperm = 100, nboot = 100)

#### 2017

# Subset only SNPs
field_snps17 <- field_snps17[,c(18:108)]

# Convert to inbreedR format
field_snps17[field_snps17 == 2] <- 0

#calculate g2
g2_field17 <- g2_snps(field_snps17, nperm = 100, nboot = 100)

### 2016

# Subset only SNPs
field_snps16 <- field_snps16[,c(18:108)]

# Convert to inbreedR format
field_snps16[field_snps16 == 2] <- 0

#calculate g2
g2_field16 <- g2_snps(field_snps16, nperm = 100, nboot = 100)

### 2015

# Subset only SNPs
field_snps15 <- field_snps15[,c(18:108)]

# Convert to inbreedR format
field_snps15[field_snps15 == 2] <- 0

#calculate g2
g2_field15 <- g2_snps(field_snps15, nperm = 100, nboot = 100)

### 2014

# Subset only SNPs
field_snps14 <- field_snps14[,c(18:108)]

# Convert to inbreedR format
field_snps14[field_snps14 == 2] <- 0

#calculate g2
g2_field14 <- g2_snps(field_snps14, nperm = 100, nboot = 100)

### 2013

# Subset only SNPs
field_snps13 <- field_snps13[,c(18:108)]

# Convert to inbreedR format
field_snps13[field_snps13 == 2] <- 0

#calculate g2
g2_field13 <- g2_snps(field_snps13, nperm = 100, nboot = 100)

### 2012

# Subset only SNPs
field_snps12 <- field_snps12[,c(18:108)]

# Convert to inbreedR format
field_snps12[field_snps12 == 2] <- 0

#calculate g2
g2_field12 <- g2_snps(field_snps12, nperm = 100, nboot = 100)

### 2011

# Subset only SNPs
field_snps11 <- field_snps11[,c(18:108)]

# Convert to inbreedR format
field_snps11[field_snps11 == 2] <- 0

#calculate g2
g2_field11 <- g2_snps(field_snps11, nperm = 100, nboot = 100)

### 2010

# Subset only SNPs
field_snps10 <- field_snps10[,c(18:108)]

# Convert to inbreedR format
field_snps10[field_snps10 == 2] <- 0

#calculate g2
g2_field10 <- g2_snps(field_snps10, nperm = 100, nboot = 100)

### 2009

# Subset only SNPs
field_snps09 <- field_snps09[,c(18:108)]

# Convert to inbreedR format
field_snps09[field_snps09 == 2] <- 0

#calculate g2
g2_field09 <- g2_snps(field_snps09, nperm = 100, nboot = 100)

####
# Make dataset
all_g2 = g2_field19$g2
g2_titles <- c('g2_field19')
p_vals <- g2_field19$p_val
CI_2.5 <- g2_field19$CI_boot[["2.5%"]]
CI_97.5 <- g2_field19$CI_boot[["97.5%"]]
Pedigree <- 'Field 2019'
Data <- '2019'

g2_field19NEW <- data.frame(g2_titles, all_g2, p_vals, CI_2.5, CI_97.5,Pedigree,Data)
g2_data19NEW <- rbind(g2_data, g2_field19NEW)

all_years <- c(g2_field19$g2,g2_field18$g2,g2_field17$g2,g2_field16$g2,
               g2_field15$g2,g2_field14$g2,g2_field13$g2,g2_field12$g2,
               g2_field11$g2,g2_field10$g2,g2_field09$g2)
mean_years <- mean(all_years)
quant_years <- CI(all_years, ci=0.95)

all_g2 = mean_years
g2_titles <- c('g2_field_all_years')
p_vals <- NA
CI_2.5 <- quant_years[3]
CI_97.5 <- quant_years[1]
Pedigree <- 'Mean Field'
Data <- 'All Years'

g2_fieldYEARS <- data.frame(g2_titles, all_g2, p_vals, CI_2.5, CI_97.5,Pedigree,Data)
g2_dataNEW <- rbind(g2_data19NEW, g2_fieldYEARS)

################################## UNIFORM #####################################

#import uniform data
uni_data1 <- read.csv("C:/Users/larathoo/Documents/20210104_Popsize40000_PS/unigene_1.csv", header = FALSE)
uni_data2 <- read.csv("C:/Users/larathoo/Documents/20210104_Popsize40000_PS/unigene_2.csv", header = FALSE)
uni_data3 <- read.csv("C:/Users/larathoo/Documents/20210104_Popsize40000_PS/unigene_3.csv", header = FALSE)
uni_data4 <- read.csv("C:/Users/larathoo/Documents/20210104_Popsize40000_PS/unigene_4.csv", header = FALSE)
uni_data5 <- read.csv("C:/Users/larathoo/Documents/20210104_Popsize40000_PS/unigene_5.csv", header = FALSE)
uni_data6 <- read.csv("C:/Users/larathoo/Documents/20210104_Popsize40000_PS/unigene_6.csv", header = FALSE)
uni_data7 <- read.csv("C:/Users/larathoo/Documents/20210104_Popsize40000_PS/unigene_7.csv", header = FALSE)
uni_data8 <- read.csv("C:/Users/larathoo/Documents/20210104_Popsize40000_PS/unigene_8.csv", header = FALSE)
uni_data9 <- read.csv("C:/Users/larathoo/Documents/20210104_Popsize40000_PS/unigene_9.csv", header = FALSE)
uni_data10 <- read.csv("C:/Users/larathoo/Documents/20210104_Popsize40000_PS/unigene_10.csv", header = FALSE)

#calculate g2
g2_uni1 <- g2_snps(uni_data1, nperm = 100, nboot = 100)
g2_uni2 <- g2_snps(uni_data2, nperm = 100, nboot = 100)
g2_uni3 <- g2_snps(uni_data3, nperm = 100, nboot = 100)
g2_uni4 <- g2_snps(uni_data4, nperm = 100, nboot = 100)
g2_uni5 <- g2_snps(uni_data5, nperm = 100, nboot = 100)
g2_uni6 <- g2_snps(uni_data6, nperm = 100, nboot = 100)
g2_uni7 <- g2_snps(uni_data7, nperm = 100, nboot = 100)
g2_uni8 <- g2_snps(uni_data8, nperm = 100, nboot = 100)
g2_uni9 <- g2_snps(uni_data9, nperm = 100, nboot = 100)
g2_uni10 <- g2_snps(uni_data10, nperm = 100, nboot = 100)

#make data frame of g2 and CIs
all_g2 <- c(g2_uni1$g2, g2_uni2$g2, g2_uni3$g2, g2_uni4$g2, g2_uni5$g2)
g2_titles <- c('uni01','uni02','uni03','uni04','uni05')
p_vals <- c(g2_uni1$p_val, g2_uni2$p_val, g2_uni3$p_val, g2_uni4$p_val, g2_uni5$p_val)
CI_2.5 <- c(g2_uni1$CI_boot[["2.5%"]],g2_uni2$CI_boot[["2.5%"]],g2_uni3$CI_boot[["2.5%"]],g2_uni4$CI_boot[["2.5%"]],g2_uni5$CI_boot[["2.5%"]])
CI_97.5 <- c(g2_uni1$CI_boot[["97.5%"]],g2_uni2$CI_boot[["97.5%"]],g2_uni3$CI_boot[["97.5%"]],g2_uni4$CI_boot[["97.5%"]],g2_uni5$CI_boot[["97.5%"]])
Pedigree <- c('Uniform','Uniform','Uniform','Uniform','Uniform')       
Data <- c('Replicate 1','Replicate 2','Replicate 3','Replicate 4','Replicate 5')

g2_dataUNI <- data.frame(g2_titles, all_g2, p_vals, CI_2.5, CI_97.5, Pedigree, Data)
g2_dataNEW2 <- rbind(g2_dataNEW, g2_dataUNI)

#Mean
mean <- mean(c(g2_uni1$g2, g2_uni2$g2, g2_uni3$g2, g2_uni4$g2, g2_uni5$g2, 
               g2_uni6$g2, g2_uni7$g2, g2_uni8$g2, g2_uni9$g2, g2_uni10$g2))
CI <- CI(c(g2_uni1$g2, g2_uni2$g2, g2_uni3$g2, g2_uni4$g2, g2_uni5$g2, 
           g2_uni6$g2, g2_uni7$g2, g2_uni8$g2, g2_uni9$g2, g2_uni10$g2),
         c=0.95)
SD_uni <- sd(c(g2_uni1$g2, g2_uni2$g2, g2_uni3$g2, g2_uni4$g2, g2_uni5$g2, 
               g2_uni6$g2, g2_uni7$g2, g2_uni8$g2, g2_uni9$g2, g2_uni10$g2))

all_g2 = mean
g2_titles <- 'Mean Uniform'
pvals <- NA
CI_2.5 <- CI[3]
CI_97.5 <- CI[1]
Pedigree <- "Mean Unif."
Data <- "Mean Uniform"

g2_data3 <- data.frame(g2_titles, all_g2, p_vals, CI_2.5, CI_97.5, Pedigree, Data)
g2_data3 <- g2_data3[1,]
g2_dataNEW3 <- rbind(g2_dataNEW2, g2_data3)

g2_dataNEW3$Pedigree <- factor(g2_dataNEW3$Pedigree, 
                               levels=c("Mean Field","Mean Ped", 
                                        "Mean Unif.", "Field 2019", 
                                        "Het.Dist.1","Het.Dist.2",
                                        "Het.Dist.3","Het.Dist.4",
                                        "Het.Dist.5","Uniform"))
#### Make Figure 3
library(ggplot2)
ggplot(g2_dataNEW3,aes(x=Pedigree, y=all_g2, fill=g2_titles)) + 
  geom_errorbar(aes(ymin=CI_2.5, ymax=CI_97.5),size=.4,width=0, position=position_dodge(width=0.7))  + 
  geom_point(size = 2, position=position_dodge(width=0.7), aes(colour = g2_titles))  + 
  ylab(expression("g"[2])) + geom_hline(yintercept=0,linetype="dashed") + 
  scale_x_discrete(name = "Simulated vs. Field") + 
  theme_classic() + theme(text = element_text(size = 16))+ 
  theme(legend.position = "none")+
  scale_color_manual(values=c("gray","gray","gray","gray","gray",
                              "gray","gray","gray","gray","gray",
                              "gray","gray","gray","gray","gray",
                              "gray","gray","gray","gray","gray",
                              "gray","gray","gray","gray","gray",
                              "deepskyblue","blue","black","gold",
                              "orange","orange","orange","orange","orange"))

################################################################################
### Calculate g2 for Linkage Groups
################################################################################

#subset field data for 8 linkage group SNPs for full data
LG1_snps <- field_snps[,c(1:13)]
LG2_snps <- field_snps[,c(14:28)]
LG3_snps <- field_snps[,c(29:38)]
LG4_snps <- field_snps[,c(39:50)]
LG5_snps <- field_snps[,c(51:62)]
LG6_snps <- field_snps[,c(63:77)]
LG7_snps <- field_snps[,c(78:83)]
LG8_snps <- field_snps[,c(84:90)]

#calculate g2
groups.list <- list(LG1_snps,LG2_snps,LG3_snps,LG4_snps,LG5_snps,LG6_snps,LG7_snps,LG8_snps)
g2_LGs <- lapply(groups.list, function(x) g2_snps(x, nperm = 100, nboot = 100))

mean_g2_LG <- (g2_LGs[[1]][[2]]+g2_LGs[[2]][[2]]+g2_LGs[[3]][[2]]+g2_LGs[[4]][[2]]+
                 g2_LGs[[5]][[2]]+g2_LGs[[6]][[2]]+g2_LGs[[7]][[2]]+g2_LGs[[8]][[2]])/8

#Subset full data for H<0.3
fulldata_lowH <- subset(fulldata, fulldata$H <= 0.3)

#convert -9,-10 and -8 to NA
fulldata_lowH[fulldata_lowH == -8] <- NA
fulldata_lowH[fulldata_lowH == -9] <- NA
fulldata_lowH[fulldata_lowH == -10] <- NA

# Subset only SNPs
field_snps_lowH <- fulldata_lowH[,c(18:108)]

# Convert to inbreedR format
field_snps_lowH[field_snps_lowH == 2] <- 0

#calculate g2
g2_field_lowH <- g2_snps(field_snps_lowH, nperm = 100, nboot = 100)

#subset low H field data for 8 linkage group SNPs
LG1_snps_lowH <- field_snps_lowH[,c(1:13)]
LG2_snps_lowH <- field_snps_lowH[,c(14:28)]
LG3_snps_lowH <- field_snps_lowH[,c(29:38)]
LG4_snps_lowH <- field_snps_lowH[,c(39:50)]
LG5_snps_lowH <- field_snps_lowH[,c(51:62)]
LG6_snps_lowH <- field_snps_lowH[,c(63:77)]
LG7_snps_lowH <- field_snps_lowH[,c(78:83)]
LG8_snps_lowH <- field_snps_lowH[,c(84:90)]

#calculate g2
groups.list.lowH <- list(LG1_snps_lowH,LG2_snps_lowH,LG3_snps_lowH,LG4_snps_lowH,
                         LG5_snps_lowH,LG6_snps_lowH,LG7_snps_lowH,LG8_snps_lowH)
g2_LGs_lowH <- lapply(groups.list.lowH, function(x) g2_snps(x, nperm = 100, nboot = 100))

mean_g2_LG_lowH <- (g2_LGs_lowH[[1]][[2]]+g2_LGs_lowH[[2]][[2]]+g2_LGs_lowH[[3]][[2]]+
                      g2_LGs_lowH[[4]][[2]]+g2_LGs_lowH[[5]][[2]]+g2_LGs_lowH[[6]][[2]]+
                      g2_LGs_lowH[[7]][[2]]+g2_LGs_lowH[[8]][[2]])/8

#Make the data file
Linkage_Groups <- c("All SNPs","Mean LGs","Mean LGs low H",
                    "1","2","3","4","5","6","7","8",
                    "1 low H","2 low H","3 low H","4 low H","5 low H","6 low H","7 low H","8 low H")
all_g2 <- c(g2_field[[2]],mean_g2_LG,mean_g2_LG_lowH,
            g2_LGs[[1]][[2]],g2_LGs[[2]][[2]],g2_LGs[[3]][[2]],g2_LGs[[4]][[2]],
            g2_LGs[[5]][[2]],g2_LGs[[6]][[2]],g2_LGs[[7]][[2]],g2_LGs[[8]][[2]],
            g2_LGs_lowH[[1]][[2]],g2_LGs_lowH[[2]][[2]],g2_LGs_lowH[[3]][[2]],g2_LGs_lowH[[4]][[2]],
            g2_LGs_lowH[[5]][[2]],g2_LGs_lowH[[6]][[2]],g2_LGs_lowH[[7]][[2]],g2_LGs_lowH[[8]][[2]])
p_vals <- c(g2_field[[3]],NA,NA,
            g2_LGs[[1]][[3]],g2_LGs[[2]][[3]],g2_LGs[[3]][[3]],g2_LGs[[4]][[3]],
            g2_LGs[[5]][[3]],g2_LGs[[6]][[3]],g2_LGs[[7]][[3]],g2_LGs[[8]][[3]],
            g2_LGs_lowH[[1]][[3]],g2_LGs_lowH[[2]][[3]],g2_LGs_lowH[[3]][[3]],g2_LGs_lowH[[4]][[3]],
            g2_LGs_lowH[[5]][[3]],g2_LGs_lowH[[6]][[3]],g2_LGs_lowH[[7]][[3]],g2_LGs_lowH[[8]][[3]])
p_vals <- c(g2_field[[3]],NA,NA,
            g2_LGs[[1]][[3]],g2_LGs[[2]][[3]],g2_LGs[[3]][[3]],g2_LGs[[4]][[3]],
            g2_LGs[[5]][[3]],g2_LGs[[6]][[3]],g2_LGs[[7]][[3]],g2_LGs[[8]][[3]],
            g2_LGs_lowH[[1]][[3]],g2_LGs_lowH[[2]][[3]],g2_LGs_lowH[[3]][[3]],g2_LGs_lowH[[4]][[3]],
            g2_LGs_lowH[[5]][[3]],g2_LGs_lowH[[6]][[3]],g2_LGs_lowH[[7]][[3]],g2_LGs_lowH[[8]][[3]])
CI_2.5 <- c(g2_field[6][[1]][["2.5%"]],NA,NA,
            g2_LGs[[1]][6][[1]][["2.5%"]],g2_LGs[[2]][6][[1]][["2.5%"]],
            g2_LGs[[3]][6][[1]][["2.5%"]],g2_LGs[[4]][6][[1]][["2.5%"]],
            g2_LGs[[5]][6][[1]][["2.5%"]],g2_LGs[[6]][6][[1]][["2.5%"]],
            g2_LGs[[7]][6][[1]][["2.5%"]],g2_LGs[[8]][6][[1]][["2.5%"]],
            g2_LGs_lowH[[1]][6][[1]][["2.5%"]],g2_LGs_lowH[[2]][6][[1]][["2.5%"]],
            g2_LGs_lowH[[3]][6][[1]][["2.5%"]],g2_LGs_lowH[[4]][6][[1]][["2.5%"]],
            g2_LGs_lowH[[5]][6][[1]][["2.5%"]],g2_LGs_lowH[[6]][6][[1]][["2.5%"]],
            g2_LGs_lowH[[7]][6][[1]][["2.5%"]],g2_LGs_lowH[[8]][6][[1]][["2.5%"]])
CI_97.5 <- c(g2_field[6][[1]][["97.5%"]],NA,NA,
             g2_LGs[[1]][6][[1]][["97.5%"]],g2_LGs[[2]][6][[1]][["97.5%"]],
             g2_LGs[[3]][6][[1]][["97.5%"]],g2_LGs[[4]][6][[1]][["97.5%"]],
             g2_LGs[[5]][6][[1]][["97.5%"]],g2_LGs[[6]][6][[1]][["97.5%"]],
             g2_LGs[[7]][6][[1]][["97.5%"]],g2_LGs[[8]][6][[1]][["97.5%"]],
             g2_LGs_lowH[[1]][6][[1]][["97.5%"]],g2_LGs_lowH[[2]][6][[1]][["97.5%"]],
             g2_LGs_lowH[[3]][6][[1]][["97.5%"]],g2_LGs_lowH[[4]][6][[1]][["97.5%"]],
             g2_LGs_lowH[[5]][6][[1]][["97.5%"]],g2_LGs_lowH[[6]][6][[1]][["97.5%"]],
             g2_LGs_lowH[[7]][6][[1]][["97.5%"]],g2_LGs_lowH[[8]][6][[1]][["97.5%"]])

g2_DATA <- data.frame(Linkage_Groups, all_g2, p_vals, CI_2.5, CI_97.5)

################################################################################
### Correlation matrix 
################################################################################
library(corrplot)
library(Hmisc)

#####################
#correlation matrices
#####################

traits <- fulldata

traits <- subset(traits, traits$StemHeightMAX < 250 & traits$StemHeightMAX >10)
traits <- subset(traits, traits$TotalFlowersMAXNEW > 0)
traits <- subset(traits, traits$TotalFruitMAX > 0)
traits <- subset(traits, traits$EstimFlowersMAX > 0 & traits$EstimFlowersMAX < 500)
traits <- subset(traits, traits$LeavesMAX >0 & traits$LeavesMAX < 90)
traits <- subset(traits, traits$NumFloweringStemsMAX>0)

trait_list <- c("TotalFruitMAX", "TotalFlowersMAX", "StemHeightMAX", "NumFloweringStemsMAX","LeavesMAX", "EstimFlowersMAX")
traitsNEW <- traits[,colnames(traits)%in%trait_list]

traits.y <- as.matrix(traitsNEW)
colnames(traits.y) <- c("Total Fruit", "Total Flowers", "Estimated Flowers", "Leaf nodes", "Stem Height", "Flowering Stems")
cor.y <-rcorr(traits.y, type = "spearman")
cor.matrix.y <- cor.y$r
corrplot(cor.y$r, type = "upper", method = "color", tl.col = "black", tl.srt = 45, p.mat = cor.y$P, sig.level = 0.05, insig = "n", order = "original", 
         addCoef.col = "grey10", cl.lim = c(0,1), col=colorRampPalette(c("blue","white","dark gray"))(200))

